---
name: Bug report
about: Create a report to report a problem that needs to be fixed
labels: bug
title: "BUG: "

---

# Description
A clear and concise description of what the bug is, including a description
of what you expected the outcome to be.

# To Reproduce this bug:
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

Consider including images or test files to help others reproduce the bug and
solve the problem.

## Test configuration
 - OS: [e.g. Hal]
 - Version [e.g. Python 3.47]
 - Other details about your setup that could be relevant

# Additional context
Add any other context about the problem here.
